import Popup from '@/components/popup'
import { FC, forwardRef, useEffect, useImperativeHandle, useState } from 'react'
import { View, Text, Image, RootPortal } from '@tarojs/components'
import styles from './index.module.scss'
import classnames from 'classnames'
import Taro from '@tarojs/taro'

interface UploadColorEvent {
  onUploadConfirm?: Function
}

interface PropsType extends UploadColorEvent {
  uploadConfirmState: boolean
}

const UploadColor = forwardRef((params: PropsType, ref) => {
  const { onUploadConfirm, uploadConfirmState } = params
  const [showModal, setShowModal] = useState(false)
  const [filePath, setFilePath] = useState('')
  const [file, setFile] = useState({})

  const handleUpload = async () => {
    Taro.chooseMedia({
      count: 1,
      mediaType: ['image'],
      sourceType: ['album'],
      success(ev) {
        setFilePath(ev.tempFiles[0].tempFilePath)
        setFile(ev.tempFiles[0])
      },
    })
  }

  useEffect(() => {
    if (uploadConfirmState) {
      setFilePath('')
      handleTriggerUploadModal(false)
    }
  }, [uploadConfirmState])

  const handleTriggerUploadModal = (bool: boolean) => {
    setShowModal(bool)
  }
  useImperativeHandle(
    ref,
    () => ({
      handleTriggerUploadModal,
    }),
    [handleTriggerUploadModal],
  )

  const handleClear = () => {
    setFilePath('')
  }
  const handleUploadConfirm = () => {
    onUploadConfirm && onUploadConfirm(file)
  }

  return (
    <View className={styles['upload-container']}>
      <Popup title='上传纹理' show={showModal} onClose={() => handleTriggerUploadModal(false)}>
        <View className={styles['u-content']}>
          <View onClick={handleUpload} className={styles['u-image']}>
            {filePath && <Image mode='aspectFill' src={filePath} />}

            <View className={classnames({ 'update-statu': filePath })}>{filePath ? '点击修改' : '点击上传'}</View>
          </View>
          <View className={styles['u-button']}>
            <View onClick={handleClear}>清除</View>
            <View onClick={handleUploadConfirm} className={styles.confirm}>
              确定
            </View>
          </View>
        </View>
      </Popup>
    </View>
  )
})
export default UploadColor
